@@ -126,8 +126,8 @@ def drag_force(rho, v, C, A):
     return (1 / 2) * rho * (v**2) * C * A
 
 
-def print_all(**args):
-    out = ""
+def print_all(*args):
+    out = []
     for arg in args:
-        out += arg.value.name_val + ", "
-    print(out)
+        out.append(arg.value.name_val)
+    print(", ".join(out))
